@@ -1,5 +1,5 @@
 package Sys::Info::OS;
-$Sys::Info::OS::VERSION = '0.7808';
+$Sys::Info::OS::VERSION = '0.7809';
 use strict;
 use warnings;
 use subs qw( LC_TYPE  );
@@ -97,9 +97,31 @@ sub meta {
 sub ip {
     my $self   = shift;
     my $hostip = Sys::HostIP->new;
-    my $ip     = $hostip->ip;;
-    $ip = $self->SUPER::_ip()
-        if $ip && $ip =~ m{ \A 127 }xms && $self->SUPER::can('_ip');
+    my $int    = $hostip->interfaces;
+
+    my $ip;
+    if ( my $eth = $int->{eth0} ) {
+        $ip = $eth;
+    }
+    else {
+        my @devs = keys %{ $int };
+
+        my @junk_keys = grep {
+            m{ docker[0-9]+ }xms
+        } @devs;
+        delete @{ $ip }->{ @junk_keys} if @junk_keys;
+
+        if ( my $i_feel_lucky = $devs[ rand @devs ] ) {
+            $ip = $i_feel_lucky;
+        }
+    }
+
+    if (
+            $ip && $ip =~ m{ \A 127 }xms
+        &&  $self->SUPER::can('_ip')
+    ) {
+        $ip = $self->SUPER::_ip()
+    }
     return $ip;
 }
 
@@ -121,7 +143,7 @@ Sys::Info::OS
 
 =head1 VERSION
 
-version 0.7808
+version 0.7809
 
 =head1 SYNOPSIS
 
